Superadmin
=====

Superadmin is a Django app based in django admin to build admin sites quickly and easily, and generate site page like django admin.

Detailed documentation is in the "docs" directory.

Quick start
-----------

1. Add "superadmin" to your INSTALLED_APPS setting like this::

    INSTALLED_APPS = [
        ...
        'superadmin',
    ]

3. Run ``python manage.py migrate`` to create the superadmin migrations.

4. Continue